﻿using System.Windows.Forms;
using System.IO;
using System;

namespace FormAndWpfTest
{
	public partial class FmMain : Form
	{
		private WpfImageHost wpfImgHost;
		private System.Windows.Controls.Image wpfImage;

		public FmMain()
		{
			InitializeComponent();
			this.Text = Application.ProductName;

			wpfImgHost = new WpfImageHost();
			wpfImage = wpfImgHost.Image;
			pnlFrame.Controls.AddRange(new Control[] { wpfImgHost });	//1個でもAddよりAddRangeの方が無難

			wpfImgHost.Dock = DockStyle.Fill;
			wpfImgHost.BackColor = System.Drawing.Color.Black;

			wpfImage.AllowDrop = true;
			wpfImage.DragEnter += new System.Windows.DragEventHandler(Image_DragEnter);
			wpfImage.Drop += new System.Windows.DragEventHandler(Image_Drop);

			wpfImage.MouseLeftButtonDown += new System.Windows.Input.MouseButtonEventHandler(Image_MouseLeftButtonDown);
			wpfImage.MouseLeftButtonUp += new System.Windows.Input.MouseButtonEventHandler(Image_MouseLeftButtonUp);
		}
		
		private void FmMain_Load(object sender, System.EventArgs e)
		{
			tscbQuality.SelectedIndex = 1;
			tscbQuality_DropDownClosed(sender, e);

			lblInfo.Text =
				"【使い方】" + Environment.NewLine +
				"・黒枠以外の部分、または表示済み画像の上に、新たな画像ファイルをドラッグ＆ドロップしてください。" + Environment.NewLine +
				"・画像をドラッグして移動させることができます。マウスカーソル移動の有効範囲は画像内のみです。" + Environment.NewLine +
				"・ツールメニューは下辺へ移動することができます。";
		}

		private void FmMain_FormClosed(object sender, FormClosedEventArgs e)
		{
			wpfImgHost.Dispose();
		}

		//Formへのドラッグ＆ドロップ
		private void FmMain_DragEnter(object sender, DragEventArgs e)
		{
			this.Activate();
			if (e.Data.GetDataPresent(DataFormats.FileDrop))
				e.Effect = System.Windows.Forms.DragDropEffects.Copy;
			else
				e.Effect = System.Windows.Forms.DragDropEffects.None;
		}
		//
		private void FmMain_DragDrop(object sender, DragEventArgs e)
		{
			string[] filePaths = (string[])e.Data.GetData(DataFormats.FileDrop);
			ShowImageFile(filePaths);
		}

		//WPFのImageへのドラッグ＆ドロップ
		private void Image_DragEnter(object sender, System.Windows.DragEventArgs e)
		{
			this.Activate();
			if (e.Data.GetDataPresent(DataFormats.FileDrop))
				e.Effects = System.Windows.DragDropEffects.Copy;
			else
				e.Effects = System.Windows.DragDropEffects.None;
		}
		//
		private void Image_Drop(object sender, System.Windows.DragEventArgs e)
		{
			string[] filePaths = (string[])e.Data.GetData(DataFormats.FileDrop);
			e.Handled = true;
			ShowImageFile(filePaths);
		}
		
		//ドラッグ＆ドロップされたファイルを描画する
		private void ShowImageFile(string[] filePaths)
		{
			if (filePaths == null || filePaths.Length == 0) return;
			bool isOK = wpfImgHost.SetBitmapImage(filePaths[0]);
			if (isOK)
			{
				this.Text = Path.GetFileName(filePaths[0]);
				lblInfo.Visible = false;
			}
		}

		//変形：回転
		private void tsbtnRot_Click(object sender, System.EventArgs e)
		{
			int degree = 0;
			try { degree = int.Parse(((sender as ToolStripButton).Tag) as string); }
			catch { return; }
			if (degree != 0) wpfImgHost.TransformRotate(degree);
		}

		//変形：反転
		private void tsbtnFlip_Click(object sender, System.EventArgs e)
		{
			if (sender == tsbtnFlipX) wpfImgHost.TransformFlip(EFlip.X);
			else if (sender == tsbtnFlipY) wpfImgHost.TransformFlip(EFlip.Y);
		}

		//変形：拡大縮小
		private void tbarZoom_Scroll(object sender, System.EventArgs e)
		{
			double scale = (double)tbarZoom.Value / 10.0;
			wpfImgHost.TransformZoom(scale);
			lblScale.Text = (tbarZoom.Value * 10) + "%";
		}

		//変形：リセット
		private void tsbtnReset_Click(object sender, System.EventArgs e)
		{
			wpfImgHost.TransformReset();
			tbarZoom.Value = 10;
			lblScale.Text = "100%";
		}

		//画質設定
		private void tscbQuality_DropDownClosed(object sender, System.EventArgs e)
		{
			EQuality[] aQuality = { EQuality.High, EQuality.Normal, EQuality.Low };
			wpfImgHost.SetImageQuality(aQuality[tscbQuality.SelectedIndex]);
		}

		//画像移動：開始
		private System.Windows.Point moveStartPos;
		private void Image_MouseLeftButtonDown(object sender, System.Windows.Input.MouseButtonEventArgs e)
		{
			wpfImgHost.Image.Cursor = System.Windows.Input.Cursors.SizeAll;	//十字方向矢印
			moveStartPos = wpfImgHost.Image.PointToScreen(e.GetPosition(wpfImgHost.Image));
		}

		//画像移動：終了
		private void Image_MouseLeftButtonUp(object sender, System.Windows.Input.MouseButtonEventArgs e)
		{
			System.Windows.Point currentPos = wpfImgHost.Image.PointToScreen(e.GetPosition(wpfImgHost.Image));
			wpfImgHost.TransformOffset(currentPos.X - moveStartPos.X, currentPos.Y - moveStartPos.Y);
			wpfImgHost.Image.Cursor = System.Windows.Input.Cursors.Arrow;
		}

	}	//class
}	//namespace
